summaryrefslogtreecommitdiff
path: root/viengoos/cap.h
diff options
context:
space:
mode:
authorNeal H. Walfield <neal@gnu.org>2008-12-17 18:45:14 +0100
committerNeal H. Walfield <neal@gnu.org>2008-12-17 18:45:14 +0100
commit4b34130b861911b2fbc62e706239d55ce817d203 (patch)
tree0fb7f4a87b0813e7884b86b7a0a7390265083a2d /viengoos/cap.h
parenta7416b7c63f4954ff78eecf31e5146cb86cda6a6 (diff)
Add a "vg_" to public viengoos identifiers.
2008-12-17 Neal H. Walfield <neal@gnu.org> * viengoos/activity.h: Add a "vg_" to public viengoos identifiers. Update users. * viengoos/addr-trans.h: Likewise. * viengoos/addr.h: Likewise. * viengoos/cap.h: Likewise. * viengoos/folio.h: Likewise. * viengoos/futex.h: Likewise. * viengoos/rpc.h: Likewise. * viengoos/thread.h: Likewise.
Diffstat (limited to 'viengoos/cap.h')
-rw-r--r--viengoos/cap.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/viengoos/cap.h b/viengoos/cap.h
index 609e4a1..d8da9a3 100644
--- a/viengoos/cap.h
+++ b/viengoos/cap.h
@@ -30,23 +30,25 @@ extern const int cap_type_num_slots[];
/* Set's the capability TARGET to point to the same object as the
capability SOURCE, however, preserves the guard in TARGET. */
static inline bool
-cap_set (struct activity *activity, struct cap *target, struct cap source)
+cap_set (struct activity *activity, struct vg_cap *target, struct vg_cap source)
{
/* This is kosher as we know the implementation of CAP_COPY. */
- return cap_copy (activity,
- ADDR_VOID, target, ADDR_VOID,
- ADDR_VOID, source, ADDR_VOID);
+ return vg_cap_copy (activity,
+ VG_ADDR_VOID, target, VG_ADDR_VOID,
+ VG_ADDR_VOID, source, VG_ADDR_VOID);
}
/* Invalidate all mappings that may depend on this object. */
-extern void cap_shootdown (struct activity *activity, struct cap *cap);
+extern void cap_shootdown (struct activity *activity, struct vg_cap *cap);
/* Return the object designated by CAP, if any. */
-struct object *cap_to_object (struct activity *activity, struct cap *cap);
+struct object *vg_cap_to_object (struct activity *activity,
+ struct vg_cap *cap);
-/* Like cap_to_object but only returns the object if it is in
+/* Like vg_cap_to_object but only returns the object if it is in
memory. */
-struct object *cap_to_object_soft (struct activity *activity, struct cap *cap);
+struct object *cap_to_object_soft (struct activity *activity,
+ struct vg_cap *cap);